# -*- perl -*-

package Bundle::Image::Info::XBM;

use strict;
use vars qw($VERSION);
$VERSION = '0.01';

1;

__END__

=head1 NAME

Bundle::Image::Info::XBM - XBM (X11 bitmap) support for Image::Info

=head1 SYNOPSIS

=for test_synopsis BEGIN { die "SKIP: shell code\n"; }

 perl -MCPAN -e 'install Bundle::Image::Info::XBM'

=end

=head1 CONTENTS

Image::Info - the base Image::Info module

Image::Xbm 1.07 - reading XBM files

=head1 DESCRIPTION

This bundle installs everything needed to get XBM support into
L<Image::Info>.

=head1 AUTHOR

Slaven Rezic <srezic@cpan.org>

=cut
